@@ -2,7 +2,7 @@
 extern crate bindgen;
 
 fn main() {
-    println!("cargo:rustc-link-lib=dylib=alib");
+    println!("cargo:rustc-link-lib=dylib=asound");
 
     #[cfg(feature = "use-bindgen")]
     generate_bindings(&_alsa_library);
